package com.recovery.admin.boot.interceptor;


import cn.dev33.satoken.stp.StpUtil;
import cn.dev33.satoken.strategy.SaStrategy;
import cn.dev33.satoken.util.SaFoxUtil;
import cn.hutool.extra.spring.SpringUtil;
import com.alibaba.fastjson.JSONObject;
import com.auth0.jwt.interfaces.DecodedJWT;

import com.recovery.admin.boot.exception.BusinessException;
import com.recovery.admin.boot.filter.RequestWrapper;
import com.recovery.common.base.config.redis.RedisCache;
import com.recovery.common.base.constant.Constants;
import com.recovery.common.base.result.ResultCode;
import com.recovery.common.base.util.RedisUtil;
import com.recovery.common.base.utils.JwtUtils;
import lombok.extern.slf4j.Slf4j;

import org.springframework.util.StringUtils;
import org.springframework.web.servlet.HandlerInterceptor;
import org.springframework.web.servlet.ModelAndView;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.Date;
import java.util.HashMap;

@Slf4j
public class JwtInterceptor implements HandlerInterceptor {

    @Resource
    RedisCache redisCache;

    public JwtInterceptor(RedisCache redisCache) {
        this.redisCache = redisCache;
    }
    @Override
    public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler) throws Exception {
        response.setHeader( "Set-Cookie" , "cookiename=httponlyTest;Path=/;Domain=domainvalue;Max-Age=seconds;HTTPOnly");
        response.setHeader( "Content-Security-Policy" , "default-src 'self'; script-src 'self'; frame-ancestors 'self'");
        response.setHeader("Access-Control-Allow-Origin", (request).getHeader("Origin"));
        response.setHeader("Access-Control-Allow-Credentials", "true");
        response.setHeader("Referrer-Policy","no-referrer");
        response.setContentType("application/json");
        response.setCharacterEncoding("UTF-8");
        // 获取当前token（这个token获取的是请求头的token，也可以用 request 获取）
        String token = StpUtil.getTokenValue();
        long tokenTimeout = StpUtil.getTokenTimeout();// 获取过期时间
        //token没过期，过期时间不是-1的时候，每次请求都刷新过期时间
        if (tokenTimeout != -1){
            StpUtil.renewTimeout(3600);// 用于token续期
        }

        if (StringUtils.isEmpty(token)) {
            throw new BusinessException(ResultCode.LOGIN_ERROR);
        }
        if (!StpUtil.isLogin()) {
            throw new BusinessException(ResultCode.IS_LOGIN_EXPIRE_ERROR);
        }
        boolean rest = redisCache.isExists(Constants.REDIS_USRE_TOKEN+token);
        if (!rest) {
            throw new BusinessException(ResultCode.LOGIN_EXPIRE_ERROR);
        }
        //把变量放在request请求域中，仅可以被这次请求，即同一个requerst使用
        request.setAttribute(Constants.LOGIN_USRE_TOKEN,token);
        try {
            //如果验证成功放行请求
//            DecodedJWT verify = JwtUtils.verifyToken(token);

            return true;
        }
        catch (Exception exception)
        {
            throw new BusinessException(ResultCode.TOKEN_INVALID_OR_EXPIRED);
        }
    }
    /**
     * @date: 2023/2/6 12:46
     * @author: zhouzhaodong
     * @description: 访问控制器方法后执行
     */
    @Override
    public void postHandle(HttpServletRequest request, HttpServletResponse response, Object handler, ModelAndView modelAndView) {
        log.info(new Date() + "--postHandle:" + request.getRequestURL());
    }

    /**
     * @date: 2023/2/6 12:46
     * @author: zhouzhaodong
     * @description: postHandle方法执行完成后执行，一般用于释放资源
     */
    @Override
    public void afterCompletion(HttpServletRequest request, HttpServletResponse response, Object handler, Exception ex) {
        log.info(new Date() + "--afterCompletion:" + request.getRequestURL());
    }

    public void renderJson(HttpServletResponse response, Object object) {
        response.reset();
        response.setHeader("Access-Control-Allow-Origin", "*");
        response.setHeader("Access-Control-Allow-Methods", "*");
        response.setHeader("Access-Control-Allow-Headers", "x-requested-with,content-type");
        response.setContentType("application/json");
        response.setCharacterEncoding("utf-8");
        try {
            response.getWriter().print(JSONObject.toJSONString(object));
        } catch (IOException e) {
            e.printStackTrace();
        }
    }
}

