package com.recovery.auth.controller;


import cn.dev33.satoken.stp.SaTokenInfo;
import cn.dev33.satoken.stp.StpUtil;
import cn.dev33.satoken.util.SaResult;
import com.recovery.auth.exception.BusinessException;
import com.recovery.auth.feign.UserFeignClient;
import com.recovery.auth.security.details.user.JwtAuthenticationRequest;
import com.recovery.auth.service.AuthService;
import com.recovery.common.base.config.redis.RedisCache;
import com.recovery.common.base.constant.Constants;
import com.recovery.common.base.dto.UserAuthDTO;
import com.recovery.common.base.dto.UserAuthorityDto;
import com.recovery.common.base.result.ApiResult;
import com.recovery.common.base.result.ResultCode;
import com.recovery.common.base.util.EncryptUtil;
import com.recovery.common.base.util.RedisUtil;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;

/**
 * @author： 
 */
@RestController
@RequestMapping("/oauth")
@AllArgsConstructor
@Slf4j
public class AuthController {

    @Resource
    AuthService authService;
    @Resource
    UserFeignClient userFeignClient;
    @Resource
    RedisCache redisCache;

    @PostMapping("/token")
    public ApiResult postAccessToken(@RequestBody JwtAuthenticationRequest authenticationRequest, HttpServletRequest request){
        log.info("----------------获取token");
        HashMap map= new HashMap();
        try {
            map = authService.login(authenticationRequest, request);
        }catch (Exception e){
            log.error("获取token："+e.getMessage(),e);
            return ApiResult.failed(e.getMessage());
        }
        return ApiResult.ok(map);
    }

    @PostMapping("/doLogin")
    public ApiResult doLogin(@RequestBody JwtAuthenticationRequest authenticationRequest) {
        if(StringUtils.isEmpty(authenticationRequest.getUsername())){
            throw new BusinessException("账户不能为空");
        }
        if(StringUtils.isEmpty(authenticationRequest.getPassword())){
            throw new BusinessException("密码不能为空");
        }

        ApiResult<UserAuthDTO> result = userFeignClient.getUserByUsername(authenticationRequest.getUsername());
        UserAuthDTO userDetails = new UserAuthDTO();
        if (ResultCode.SUCCESS.getCode().equals(result.getCode())) {
            userDetails = result.getData();
        }
        // 数据库中查询数据进行比对
        if (userDetails.getUserName().equals(authenticationRequest.getUsername()) && userDetails.getPassword().equals(EncryptUtil.encrypt(authenticationRequest.getPassword()))) {
            log.info("密码校验成功！");
            StpUtil.login(userDetails.getUserId(),"PC");
        }else {
            return ApiResult.failed("密码错误");
        }
        //认证通过 使用userid 储存用户信息
        try {
            redisCache.put_obj(Constants.REDIS_USRE_INFO + userDetails.getUserId(),userDetails , Constants.REDIS_TOKEN_TIME);
        } catch (Exception e) {
            log.error("redis储存token报错"+e.getMessage(),e);
        }
        // 第3步，返回给前端
        SaTokenInfo tokenInfo = StpUtil.getTokenInfo();
        HashMap map= new HashMap();
        map.put("token",tokenInfo.getTokenValue());
        map.put("user",userDetails);
        return ApiResult.ok(map);
    }

//    @GetMapping("/public-key")
//    public Map<String, Object> getPublicKey() {
//       //单例模式
//
//        return “吃啥;
//    }
}
