package com.recovery.common.base.config.redis;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.data.redis.core.ValueOperations;
import org.springframework.stereotype.Component;

import java.util.Set;
import java.util.concurrent.TimeUnit;

@Component("BaseRedisCacheImpl")
public class BaseRedisCacheImpl implements BaseRedisCache {

    @Autowired
    private StringRedisTemplate redisTemplate;

    @Autowired
    private RedisTemplate<String, Object> redisTemplate_obj;


    @Override
    public String get(String key) {
        ValueOperations<String, String> operations = redisTemplate.opsForValue();
        return operations.get(key);
    }

    @Override
    public Object get_obj(String key) {
        return redisTemplate_obj.opsForValue().get(key);
    }

    @Override
    public void remove(String key) {
        if (redisTemplate.hasKey(key)) {
            redisTemplate.delete(key);
        }
    }

    @Override
    public void put(String key, String value) {
        try {
            if(value == null) {
                value = "";
            }
            ValueOperations<String, String> operations = redisTemplate.opsForValue();
            operations.set(key, value);
        } catch (Exception err) {

        }
    }

    @Override
    public void put_obj(String key, Object value) {
        redisTemplate_obj.opsForValue().set(key,value);
    }

    @Override
    public void put(String key, String value, int second) {
        if(value == null) {
            value = "";
        }
        ValueOperations<String, String> operations = redisTemplate.opsForValue();
        operations.set(key, value, second, TimeUnit.SECONDS);
    }
    @Override
    public void put_obj(String key, Object value, int second) {
        redisTemplate_obj.opsForValue().set(key, value, second, TimeUnit.SECONDS);
    }
    @Override
    public long incr(String key, long value) {
        ValueOperations<String, String> operations = redisTemplate.opsForValue();
        return operations.increment(key,value);
    }

    @Override
    public void expire(String key) {
        try {
            redisTemplate.expire(key, 15, TimeUnit.DAYS);
        } catch (Exception err) {

        }
    }

    @Override
    public void expireDays(String key, int days) {
        try {
            redisTemplate.expire(key, days, TimeUnit.DAYS);
        } catch (Exception err) {

        }
    }

    @Override
    public Boolean isExists(String key) {
        if(redisTemplate.hasKey(key)){
            return true;
        }
        return false;
    }

    @Override
    public Set<String> keySet(String patten) {
        return redisTemplate.keys(patten);
    }

    @Override
    public void clean(String patten) {
        Set<String> keys = redisTemplate.keys(patten);
        if(keys.size() > 0) {
            redisTemplate.delete(keys);
        }
    }
}
